@@ -3,7 +3,7 @@
 #
 
 import logging
-
+from colorama import Fore
 import click
 
 logger = logging.getLogger(__name__)
@@ -26,9 +26,9 @@ def logging_est(logfile_path, debug=False):
     )
     logger = logging.getLogger()
     if debug is True:
-        logger.setLevel(20)
+        logger.setLevel(10)
         print_info("Debug Logging is enabled.")
-    print_info("Logging Started")
+    print_debug("Logging Started")
 
 
 def print_debug(print_obj):
@@ -40,18 +40,19 @@ def print_debug(print_obj):
 
     # Uncomment below line if want more detailed logs on console.
     # It would be better if we can provide an option to user to send debug flag.
-
-    #click.secho(f"DEBUG: {str(print_obj)}", fg="green")
+    if logger.isEnabledFor(10):
+        click.secho(f"DEBUG: {str(print_obj)}", fg="bright_blue")
     logger.debug(str(print_obj))
 
 
-def print_info(print_obj):
+def print_info(print_obj, stdout=True):
     """
     Call this function with a log message to prefix the message with INFO
     :param print_obj: Object to print to logfile and stdout
     :type print_obj: type depends on objecting being passed. Typically str
     """
-    click.secho(f"INFO: {print_obj}")
+    if stdout:
+        click.secho(f"INFO: {print_obj}")
     logger.info(str(print_obj))
 
 
@@ -65,12 +66,15 @@ def print_warning(print_obj):
     logger.warning(str(print_obj))
 
 
-def print_exception(print_obj):
+def print_exception(print_obj, ref="dxi-generic", stdout=True):
     """
     Call this function with a log message to prefix the message with EXCEPTION
     :param print_obj: Object to print to logfile and stdout
-    :type print_obj: type depends on objecting being passed. Typically str
+    :type print_obj: type depends on objectxing being passed. Typically str
 
     """
-    click.secho(str(print_obj), fg="red")
-    logger.error("EXCEPTION: %s" % (str(print_obj)))
+    err_msg = "EXCEPTION: " \
+              "{module_ref} :{err}".format(module_ref=ref,err=str(print_obj))
+    if stdout:
+        click.secho(err_msg, fg="red")
+    logger.error(" %s" % (err_msg))
