@@ -4,7 +4,8 @@
 
 
 from datetime import datetime
-
+from pytz import UTC
+from pytz import timezone
 from dateutil import tz
 from delphixpy.v1_10_2 import exceptions
 from delphixpy.v1_10_2.web import database
@@ -16,7 +17,12 @@ from delphixpy.v1_10_2.web import sourceconfig
 from delphixpy.v1_10_2.web import vo
 from delphixpy.v1_10_2.web.service import time
 from delphixpy.v1_10_2.web import selfservice
+from delphixpy.v1_10_2.web import environment
+from delphixpy.v1_10_2.web import snapshot
+
 from . import dlpx_exceptions
+from dxi._lib import dx_logging as log
+from dxi._lib.util import convert_string_to_datetime
 
 
 def convert_timestamp(engine, timestamp):
@@ -45,26 +51,57 @@ def convert_timestamp(engine, timestamp):
         return None
 
 
-def convert_timestamp_toiso(engine, timestamp):
+def convert_timestamp_toiso(engine_session, timestamp):
     """
-    Convert timezone from Zulu/UTC to the Engine's timezone
-    :param engine: A Delphix engine session object
-    :type engine: lib.get_session.GetSession object
-    :param timestamp: the timstamp in Zulu/UTC to be converted
-    :type timestamp: str
-    :return: Timestamp converted localtime
+    Convert the provided timestamp to UTC.
+    Args:
+        engine_session: A Delphix engine session object
+        timestamp: Timestamp in Engine's timezone.
+    Returns:
+        isotime: Iso Format timestamp in UTC Timezone.
     """
-
-    default_tz = tz.gettz("UTC")
-    engine_tz = time.time.get(engine)
+    utc_tz = tz.gettz("UTC")
     try:
-        convert_tz = tz.gettz(engine_tz.system_time_zone)
-        utc = datetime.strptime(timestamp, "%Y-%m-%dT%H:%M:%S")
-        utc = utc.replace(tzinfo=default_tz)
-        converted_tz = utc.astimezone(convert_tz)
-        isotime = converted_tz.isoformat()
+        engine_time_config = time.time.get(engine_session)
+        engine_tz_str = engine_time_config.system_time_zone
+        engine_tz = timezone(engine_tz_str)
+        ts = datetime.strptime(timestamp, '%Y-%m-%dT%H:%M:%S')
+        ts_in_engine_tz = engine_tz.localize(ts)
+        ts_in_utc = ts_in_engine_tz.astimezone(utc_tz)
+        isotime = ts_in_utc.isoformat()
         return isotime
-    except TypeError:
+    except TypeError as err:
+        log.print_exception(f"Error while converting the timstamp that was passed.")
+        return None
+
+def convert_timestamp_dbtz_to_utc(timestamp, db_tz, iso_format= False):
+    """
+    Convert timestamp from the DB timezone to UTC.
+    Args:
+        engine_session: A Delphix engine session object
+        timestamp: Timestamp value provided by customer.
+        db_tz: The timezone of the DB/Snapshot.
+    Returns:
+        converted_ts: timestamp in UTC timezone.
+    """
+    utc_tz = tz.gettz("UTC")
+    try:
+        if db_tz is None:
+            raise Exception("Invalid timezone string.")
+        database_tz = timezone(db_tz.split(",")[0])
+        if not isinstance(timestamp, datetime):
+            timestamp = convert_string_to_datetime(timestamp)
+        if timestamp.tzinfo is None or timestamp.tzinfo.utcoffset(timestamp) is None: # noqa
+            timestamp = database_tz.localize(timestamp)
+        converted_ts = timestamp.astimezone(utc_tz)
+        if iso_format:
+            converted_ts = converted_ts.isoformat()
+        return converted_ts
+    except TypeError as err:
+        log.print_exception(f"Error while converting the timstamp that was passed: {err}")
+        return None
+    except Exception as err:
+        log.print_exception(f"Error while converting the timstamp that was passed: {err}")
         return None
 
 
@@ -85,7 +122,7 @@ def get_running_job(engine, object_ref):
         return None
 
 
-def find_obj_by_name(engine, f_class, obj_name):
+def find_obj_by_name(engine, f_class, obj_name, env_name=None):
     """
     Function to find objects by name and object class
     :param engine: A Delphix DDP session object
@@ -96,12 +133,33 @@ def find_obj_by_name(engine, f_class, obj_name):
     :type obj_name: str
     :return: object of f_class type
     """
-    obj_list = f_class.get_all(engine)
+    if env_name:
+        obj_list = f_class.get_all(engine, env_name)
+    else:
+        obj_list = f_class.get_all(engine)
     for obj in obj_list:
         if obj.name == obj_name:
             return obj
     raise dlpx_exceptions.DlpxObjectNotFound(f"Object {obj_name} not found.")
 
+def find_obj_by_name_v2(engine, f_class, obj_name, *args, **kwargs):
+    """
+    Function to find objects by name and object class
+    :param engine: A Delphix DDP session object
+    :type engine: lib.GetSession.GetSession object
+    :param f_class: The objects class. I.E. database or timeflow.
+    :type f_class: Supported class type by Delphix
+    :param obj_name: The name of the object
+    :type obj_name: str
+    :return: object of f_class type
+    """
+    obj_name = obj_name.lower()
+    obj_list = f_class.get_all(engine, *args, **kwargs)
+    for obj in obj_list:
+        if str.lower(obj.name) == obj_name:
+            return obj
+    raise dlpx_exceptions.DlpxObjectNotFound(f"Object {obj_name} not found.")
+
 
 def find_source_obj_by_containerref(engine, f_class, containerref):
     """
@@ -170,7 +228,6 @@ def find_obj_by_reference(engine, f_class, reference):
         f"Object with reference {reference} not found."
     )
 
-
 def find_source_by_db_name(engine, obj_name):
     """
     Function to find sources by database name and object class, and return
@@ -213,7 +270,7 @@ def find_obj_name(engine, f_class, obj_reference):
         raise dlpx_exceptions.DlpxException(err)
 
 
-def find_db_repo(engine, install_type, f_environment_ref, f_install_path):
+def find_db_repo(engine, install_type, f_environment_ref, f_install_path, install_path_lookup_key=None):
     """
     Function to find database repository objects by environment reference and
     install path, and return the object's reference as a string
@@ -242,8 +299,17 @@ def find_db_repo(engine, install_type, f_environment_ref, f_install_path):
             ):
                 return obj.reference
         elif install_type == "AppDataRepository":
-            if obj.type == install_type and obj.parameters['name'] == f_install_path:
-                return obj.reference
+            try:
+                if install_path_lookup_key:
+                    if install_path_lookup_key in obj.parameters and obj.parameters[install_path_lookup_key] == f_install_path:
+                        return obj.reference
+                elif obj.type == install_type and obj.parameters['name'] == f_install_path:
+                    return obj.reference
+            except KeyError:
+                if obj.type == install_type and obj.parameters['repositoryName'] == f_install_path:
+                    return obj.reference
+                else:
+                    return None
         else:
             raise dlpx_exceptions.DlpxException(
                 f"Only OracleInstall, AppDataRepository or MSSqlInstance "
@@ -414,4 +480,99 @@ def find_obj_list_by_containername(obj_lst, container_name):
         if container_name == obj.container:
             return obj
     raise dlpx_exceptions.DlpxObjectNotFound(
-        f"Did not find any object with containername:{container_name}\n")
\ No newline at end of file
+        f"Did not find any object with containername:{container_name}\n")
+
+def find_all_snapshots(engine_session, container_ref, timeflow_ref=None, from_date=None, to_date=None, timestamp=None):
+    """
+    Retrieves all snapshots for a specific dataset
+    with the specified filters applied.
+    Allowed filters:
+        timeflow_ref: Retrieve snapshots from a specific timeflow.
+        from_date: Retrive snapshots after this date.
+        to_date: Retrieve snapshots before this date.
+    Args:
+        engine_session: Session to Delphix Engine
+        container_ref: Reference to the dataset.
+        timeflow_ref: Reference to timeflow
+        from_date: Start date for snapshot.
+        to_date: End date for snapshot.
+    Returns:
+        snapshot_obj: A TimeflowSnapshot object.
+    Raises:
+        Exception: Generic Exception
+    """
+    try:
+        snapshots = snapshot.get_all(
+            engine=engine_session,
+            database=container_ref,
+            from_date=from_date,
+            to_date=to_date
+        )
+        return snapshots
+    except Exception as err:
+        raise Exception(f"There was an error retrieving snapshot for the specified timestamp.{err}")
+
+def find_snapshot_by_timestamp(engine_session, container_ref, timestamp):
+    """
+    Returns the snapshots which can be used to provision
+    to this timestamp for the given container.
+    Allowed filters:
+        timestamp: Timestamp to filter by.
+        container_ref: VDB or vFile container object.
+    Args:
+        engine_session: Session to Delphix Engine
+        container_ref: VDB or vFile container object.
+        from_date: Start date for snapshot.
+        to_date: End date for snapshot.
+        timestamp: Timestamp to filter by.
+    Returns:
+        snapshot_obj: A TimeflowSnapshot object.
+    Raises:
+        Exception: Generic Exception
+    """
+    db_tz = None
+    utc = UTC
+    try:
+        # unfortunately, we have to find the timezone of the DB
+        # to do this, retrieve snapshots and find the timezone.
+        all_snapshots = find_all_snapshots(engine_session,container_ref)
+        if all_snapshots is None:
+            raise Exception("No snapshots found for the VDB/vFile.")
+        db_tz = all_snapshots[0].timezone
+        ts_in_utc = convert_timestamp_dbtz_to_utc(timestamp, db_tz, iso_format=True)
+        snapshots = snapshot.find_by_timestamp(
+            engine=engine_session,
+            container=container_ref,
+            timestamp=ts_in_utc
+        )
+        #ts_in_utc = datetime.fromisoformat(ts_in_utc)
+        #ts_in_utc= datetime.strptime(ts_in_utc,'%Y-%m-%dT%H:%M:%S.%fZ')
+        return (db_tz, snapshots)
+    except Exception as err:
+        raise Exception(f"There was an error retrieving "
+                        f"snapshot for the specified timestamp: {err}")
+
+
+def find_db_timezone(engine_session, container_ref):
+    """
+    Returns the timezone for the given container.
+    Args:
+        engine_session: Session to Delphix Engine
+        container_ref: VDB or vFile container object.
+    Returns:
+        timezone: Timezone string.
+    Raises:
+        Exception: Generic Exception
+    """
+    db_tz = None
+    try:
+        # TODO: Find a better way to do this?
+        all_snapshots = find_all_snapshots(engine_session,container_ref)
+        if all_snapshots is None:
+            raise Exception("No snapshots found for the VDB/vFile.")
+        for snapshot_obj in all_snapshots:
+            db_tz = snapshot_obj.timezone
+            break
+        return db_tz
+    except Exception as err:
+        raise Exception(f"Unable to find the database timezone:{err}")
