@@ -14,12 +14,14 @@ from delphixpy.v1_10_2 import exceptions
 from delphixpy.v1_10_2 import job_context
 from delphixpy.v1_10_2 import web
 from delphixpy.v1_10_2.delphix_engine import DelphixEngine
+from dxi._lib import dxi_constants as const
 
 from . import dlpx_exceptions
 from . import dx_logging
 from . import util
-
-VERSION = "v.0.3.001"
+from .util import DXIConfigConstantsHelper
+from .dlpx_exceptions import DXIException
+from .util import format_err_msg
 
 
 class GetSession:
@@ -32,7 +34,7 @@ class GetSession:
         self.dlpx_ddps = {}
         self.jobs = {}
 
-    def get_config(self, config_file_path="./config/dxtools.conf"):
+    def get_config(self, config_file_path=DXIConfigConstantsHelper().get_config()):
         """
         This method reads in the dxtools.conf file
 
@@ -112,6 +114,9 @@ class GetSession:
         # ):
         ssl._create_default_https_context = ssl._create_unverified_context
         try:
+            dx_logging.print_info(
+                f"Initiating connection with Delphix Engine. This may take a minute."
+            )
             self.server_session = DelphixEngine(
                 f_engine_address,
                 f_engine_username,
@@ -120,15 +125,11 @@ class GetSession:
                 enable_https,
             )
             self.server_wait(f_engine_address)
-        except (
-            exceptions.HttpError,
-            exceptions.RequestError,
-            exceptions.JobError,
-        ) as err:
-            raise dlpx_exceptions.DlpxException(
-                f"ERROR: An error occurred while authenticating to "
-                f"{f_engine_address}:\n {err}\n"
+            dx_logging.print_info(
+                f"Connected. Session Established."
             )
+        except DXIException as err:
+            raise err
         except (TimeoutError) as err:
             raise dlpx_exceptions.DlpxException(
                 f"ERROR: Timeout while authenticating to "
@@ -136,7 +137,7 @@ class GetSession:
             )
         except (Exception) as err:
             raise dlpx_exceptions.DlpxException(
-                f"ERROR: Error while authenticating"
+                f"ERROR: Error while authenticating to "
                 f"{f_engine_address}:{err}"
             )
 
@@ -188,19 +189,33 @@ class GetSession:
                 err_msg = ""
                 if hasattr(err,'status'):
                     if getattr(err,'status') == 401:
-                        err_msg = f"Unable to login to Delphix Engine: " \
-                                  f"{f_engine_address} with the provided credentials"
-                        raise Exception(err_msg)
+                        err_msg = format_err_msg(
+                            const.MSG_AUTH_FAILED1.format(f_engine_address),
+                            err_code=const.ERR_AUTH_FAILED,
+                            action=const.ACTION_AUTH_FAILED
+                        )
+                        raise DXIException(err_msg, const.ERR_AUTH_FAILED)
             except (exceptions.RequestError) as err:
-                err_msg = f"Unable to login to Delphix Engine:" \
-                          f"{f_engine_address} \n\t{err.args[0].details}\n\t" \
-                          f"{err.args[0].action}"
-                raise Exception(err_msg)
+                err_msg = format_err_msg(
+                    const.MSG_AUTH_FAILED1.format(f_engine_address),
+                    msg2=err.args[0].details,
+                    err_code=const.ERR_AUTH_FAILED,
+                    action=err.args[0].action
+                )
+                dx_logging.print_exception(err_msg, ref=const.ERR_AUTH_FAILED, stdout=False)
+                raise DXIException(err_msg, const.ERR_AUTH_FAILED)
             except Exception as err:
                 pass
             if time() > timeout:
-                raise Exception(" Authentication request to Delphix Engine timedout [60s]")
-            dx_logging.print_info("Waiting for response from Delphix Engine")
+                err_msg = format_err_msg(
+                    const.MSG_AUTH_TIMEOUT1.format(f_engine_address),
+                    msg2= const.MSG_AUTH_TIMEOUT2,
+                    err_code=const.ERR_AUTH_TIMEDOUT,
+                    action=const.ACTION_AUTH_TIMEOUT
+                )
+                dx_logging.print_exception(err_msg, ref=const.ACTION_AUTH_TIMEOUT, stdout=False)
+                raise DXIException(err_msg, const.ERR_AUTH_TIMEDOUT)
+            dx_logging.print_info("Waiting to successfully authenticate to Delphix Engine.")
             sleep(5)
 
 
