@@ -11,11 +11,37 @@ from cryptography.exceptions import InvalidTag
 from cryptography.hazmat.backends import default_backend
 from cryptography.hazmat.primitives import hashes
 from cryptography.hazmat.primitives.ciphers.aead import ChaCha20Poly1305
+from colorama import Fore,Style
 from delphixpy import exceptions
 from dxi._lib import dlpx_exceptions
+from dxi._lib import dxi_constants as const
+from dateutil import parser
 
 from . import dx_logging as log
 
+class DXIConfigConstantsHelper(object):
+    DXIDATA = "dxi-data"
+    CONF = '/config/dxtools.conf'
+    LOG= '/logs/'
+
+    ROOT_DEFAULT = os.path.dirname(os.path.abspath(__file__))+'/../../'
+
+    def get_dxidata_root(self):
+        root = os.environ.get('DXI_DIR', self.ROOT_DEFAULT)
+        if not root.endswith('/'):
+            root = root + '/'
+
+        if root == '/dxi-data/':
+            return root
+        else:
+            return root + self.DXIDATA
+
+    def get_config(self):
+        return self.get_dxidata_root() + self.CONF
+
+    def get_logdir(self):
+        return self.get_dxidata_root() + self.LOG
+
 def find_config_path(config_file_path):
     """
     Locate the config path if the default is passed.
@@ -41,23 +67,21 @@ def find_config_path(config_file_path):
                     f"Config location passed to dxi does not exist. "
                     f"Scanning default location."
                 )
-                config_file_path = str(
-                    os.path.join(
-                        os.path.dirname(__file__),
-                        "..",
-                        "..",
-                        "dxi-data/config/dxtools.conf",
-                    )
-                )
+                config_file_path = DXIConfigConstantsHelper().get_config()
+                #config_file_path = os.path.abspath(config_file_path)
+
             if not os.path.isfile(config_file_path):
-                err_msg = (
-                    f"Error: Could not find dxtools.conf at the "
-                    f"default location or the passed location,\n "
-                    f"dxi requires that you provide a full path "
-                    f"to dxtools.conf file (including filename)"
+                err_msg = format_err_msg(
+                    const.MSG_CONFIG_NOTFOUND1,
+                    msg2=const.MSG_CONFIG_NOTFOUND2,
+                    err_code=const.ERR_CONFIG_NOTFOUND,
+                    action=const.ACTION_CONFIG_NOTFOUND
+                )
+                #log.print_exception(err_msg)
+                raise dlpx_exceptions.DXIException(
+                    err_msg,
+                    const.ERR_CONFIG_NOTFOUND
                 )
-                log.print_exception(err_msg)
-                raise Exception(err_msg)
         log.print_debug("Config file path is: {}".format(config_file_path))
         return config_file_path
     except Exception as err:
@@ -92,24 +116,26 @@ def find_log_path(log_path, module_name):
                     f"Logs location passed to dxi does not exist. "
                     f"Using default location."
                 )
-                log_file_path = str(
-                    os.path.join(
-                        os.path.dirname(__file__), "..", "..", "dxi-data/logs"
-                    )
-                )
+                log_file_path = DXIConfigConstantsHelper().get_logdir()
+
             if not os.path.isdir(log_file_path):
-                err_msg = (
-                    f"Error: Could not find logs directory "
-                    f"at default location or the passed location.\n "
-                    f"Please review the inputs and retry)"
+                err_msg = format_err_msg(
+                    const.MSG_LOG_NOTFOUND1,
+                    msg2=const.MSG_LOG_NOTFOUND2,
+                    err_code=const.ERR_LOG_NOTFOUND,
+                    action=const.ACTION_LOG_NOTFOUND
+                )
+
+                raise dlpx_exceptions.DXIException(
+                    err_msg,
+                    const.ERR_LOG_NOTFOUND
                 )
-                log.print_exception(err_msg)
-                raise Exception(err_msg)
             log_file_path = os.path.abspath(log_file_path)
             log_file_path = str(
                 os.path.join(log_file_path, "{}.log".format(module_name))
             )
             log.print_debug("Log file path is: {}".format(log_file_path))
+
         return log_file_path
     except Exception as err:
         raise Exception(
@@ -337,10 +363,10 @@ def init_global_config_folders(config, log_dir):
             f"resolving config and log root directories {err}"
         )
     try:
-        log.print_info("Log Directory full path " + log_path)
+        log.print_debug("Log Directory full path " + log_path)
         if not os.path.exists(log_path):
             os.makedirs(log_path, exist_ok=True)
-        log.print_info(f"Log directory created @ {log_path}")
+        log.print_info(f"Log directory created at {log_path}")
     except Exception as err:
         log.print_exception(
             f"init_global_config_folders(): "
@@ -348,17 +374,11 @@ def init_global_config_folders(config, log_dir):
         )
         raise err
     try:
-        log.print_info("Config Directory full path " + config_path)
+        log.print_debug("Config Directory full path " + config_path)
         if not os.path.exists(config_path):
             os.makedirs(os.path.dirname(config_path), exist_ok=True)
-        # copy2(get_abs_path("../config/dxtools.conf"), config_path)
         _add_default_config_value(config_path)
-        log.print_debug(f"Config folder created at @ {config_path}")
-        # log.warn(
-        #     f"ACTION REQUIRED:"
-        #     f"\n\tPlease create a dxtools.conf file @ {config_path}"
-        #     f"\n\tand add your Delphix Engine information into the file."
-        # )
+        log.print_debug(f"Config directory created at @ {config_path}")
     except Exception as err:
         log.print_exception(
             f"init_global_config_folders(): "
@@ -378,6 +398,9 @@ def get_abs_path(relative_path, base_dir=__file__):
     Raises:
         Exception: General Exception
     """
+    if str(relative_path).startswith("/"):
+        return relative_path
+
     try:
         path = os.path.dirname(base_dir)
         levels = relative_path.split("/")
@@ -439,7 +462,64 @@ def _add_default_config_value(config_path):
         },
     }
     log.print_info(
-        "Config full path is: {config_path} ".format(config_path=config_path)
+        "Config file created at {config_path} ".format(config_path=config_path)
     )
     with open(config_path, "w+") as out:
         json.dump(info, out, indent=4)
+
+
+def format_err_msg(
+        msg1,
+        msg2=None,
+        engine_name=None,
+        object_name=None,
+        err_code='ERR_DXI_GEN',
+        operation=None,
+        action='Rectify the error and re-try.'
+):
+    '''
+    Function to format an error message to print for user.
+    Format:
+        error_code: msg1
+        msg2
+        Details: Engine - engine_name, Object - object_name, Operation - operation
+        Possible Action: action
+    Args:
+        msg1: Error message string
+        msg2: Error message descriptive string.
+        engine_name: Name (hostname/ip) of the engine where error occurred.
+        object_name: Name of the Delphix data object
+        err_code: An error code if applicable
+        operation: The delphix operation ( refresh, rewind etc) related to failure
+        action: Possible resolution
+
+    Returns:
+        err_str: A formatted error message.
+    '''
+    # e = '{}:\n\t{}\n\t{}\n\tDetails- Engine:{}, Object:{}, ' \
+    #     'Operation:{}\n\n\tPossible Action: {}'.format(
+    #     err_code,
+    #     msg1,
+    #     msg2,
+    #     engine_name,
+    #     object_name,
+    #     operation,
+    #     action
+    # )
+    e = f"{Fore.RED}{err_code}{Style.RESET_ALL}:\n\t{msg1}\n\t{msg2}" \
+        f"\n\tDetails- Engine:{engine_name}, Object:{object_name}, " \
+        f"Operation:{operation}\n\n\tPossible Action: {action}"
+    return e
+
+def convert_string_to_datetime(tstr):
+    """
+    Converts timestamp in string format to datetime.
+    Args:
+        tstr (string): Timestamp string.
+    Returns:
+        ts_dt (datetime): Timestamp as a datetime object
+    Raises:
+        Exception: General Exception.
+    """
+    ts_dt = parser.parse(tstr)
+    return ts_dt
\ No newline at end of file
