@@ -6,6 +6,8 @@
     [create | update | share | unshare | list | delete]
 """
 
+from os.path import basename
+
 from delphixpy.v1_10_2 import exceptions
 from delphixpy.v1_10_2.web import selfservice
 from delphixpy.v1_10_2.web import vo
@@ -16,6 +18,7 @@ from dxi._lib import run_job
 from dxi._lib.dxi_constants import BookmarkOps
 from dxi._lib.dxi_constants import DataLayoutType
 from dxi._lib.run_async import run_async
+from dxi._lib.util import DXIConfigConstantsHelper
 from dxi.dxi_tool_base import DXIBase
 from tabulate import tabulate
 
@@ -27,20 +30,20 @@ class BookmarkConstants(object):
 
     SINGLE_THREAD = False
     POLL = 20
-    CONFIG = "../../dxi-data/config/dxtools.conf"
-    LOG_FILE_PATH = "../../dxi-data/logs/"
+    CONFIG = DXIConfigConstantsHelper().get_config()
+    LOG_FILE_PATH = DXIConfigConstantsHelper().get_logdir()
     ENGINE_ID = "default"
     PARALLEL = 5
     TYPE = None
     ACTION = None
     HOSTIP = None
-    MODULE_NAME = __name__
+    MODULE_NAME = basename(__file__).split(".")[0]
     LIST_HEADER = [
         "Bookmark Name",
         "Bookmark Reference",
         "Branch",
         "Bookmark Type",
-        "DataLayout Name",
+        "Dataset Name",
         "Tags",
     ]
 
@@ -57,12 +60,13 @@ class DXIBookmark(DXIBase):
         self,
         engine=BookmarkConstants.ENGINE_ID,
         log_file_path=BookmarkConstants.LOG_FILE_PATH,
-        config_file=BookmarkConstants.CONFIG,
+        config=BookmarkConstants.CONFIG,
         poll=BookmarkConstants.POLL,
         single_thread=BookmarkConstants.SINGLE_THREAD,
         parallel=BookmarkConstants.PARALLEL,
         action=BookmarkConstants.ACTION,
         module_name=BookmarkConstants.MODULE_NAME,
+        debug=False,
     ):
         """
         :param engine: Identifier for the Delphix engine in dxtools.conf
@@ -71,8 +75,8 @@ class DXIBookmark(DXIBase):
         :param log_file: Log file for the module
         :type log_file: `str`
 
-        :param config_file: Location (including filename) of the config file
-        :type config_file: `str`
+        :param config: Location (including filename) of the config file
+        :type config: `str`
 
         :param poll: The number of seconds to wait between job polls
         :type poll: `str`
@@ -95,11 +99,12 @@ class DXIBookmark(DXIBase):
         super().__init__(
             parallel=parallel,
             poll=poll,
-            config=config_file,
+            config=config,
             log_file_path=log_file_path,
             single_thread=single_thread,
             module_name=module_name,
             engine=engine,
+            debug=debug,
         )
         self.action = action
         self.tags = ""
@@ -119,6 +124,7 @@ class DXIBookmark(DXIBase):
         self.action = BookmarkOps.LIST
         self.tags = tags
         try:
+            log.print_info(f"Running dxi bookmark list.")
             self._execute_operation(self._list_bookmark_helper)
             return True
         except Exception:
@@ -158,6 +164,7 @@ class DXIBookmark(DXIBase):
         self.timestamp = timestamp
         self.expires = expires
         try:
+            log.print_info(f"Running dxi bookmark create.")
             self._execute_operation(self._create_bookmark_helper)
             return True
         except Exception:
@@ -170,6 +177,7 @@ class DXIBookmark(DXIBase):
         self.action = BookmarkOps.SHARE
         self.bookmark_name = bookmark_name
         try:
+            log.print_info(f"Running dxi bookmark share.")
             self._execute_operation(self._share_bookmark_helper)
             return True
         except Exception:
@@ -182,6 +190,7 @@ class DXIBookmark(DXIBase):
         self.action = BookmarkOps.UNSHARE
         self.bookmark_name = bookmark_name
         try:
+            log.print_info(f"Running dxi bookmark unshare.")
             self._execute_operation(self._unshare_bookmark_helper)
             return True
         except Exception:
@@ -205,6 +214,7 @@ class DXIBookmark(DXIBase):
         self.new_bookmark_name = new_bookmark_name
         self.description = description
         try:
+            log.print_info(f"Running dxi bookmark update.")
             self._execute_operation(self._update_bookmark_helper)
             return True
         except Exception:
@@ -217,6 +227,7 @@ class DXIBookmark(DXIBase):
         self.action = BookmarkOps.DELETE
         self.bookmark_name = bookmark_name
         try:
+            log.print_info(f"Running dxi bookmark delete.")
             self._execute_operation(self._delete_bookmark_helper)
             return True
         except Exception:
@@ -315,18 +326,13 @@ class DXIBookmark(DXIBase):
                                 )
                             )
                         )
-                print("\n")
                 print(
                     tabulate(
                         display_list,
                         headers=BookmarkConstants.LIST_HEADER,
-                        tablefmt="grid",
+                        tablefmt="github",
                     )
                 )
-            self._add_last_job_to_track(dlpx_obj)
-            run_job.track_running_jobs(
-                engine_ref, dlpx_obj, poll=self.poll, failures=self.failures
-            )
             return bookmark_list
         except (
             dxe.DlpxException,
@@ -486,10 +492,12 @@ class DXIBookmark(DXIBase):
                 f"created. ERROR :{err}"
             )
             self.failures[0] = True
-            # raise dxe.DlpxException(
-            #     f"The bookmark {self.bookmark_name} was not "
-            #     f"created. ERROR :{err}"
-            # )
+        except Exception as err:
+            log.print_exception(
+                f"The bookmark {self.bookmark_name} was not created.\n"
+                f"ERROR :{err}"
+            )
+            self.failures[0] = True
 
     @run_async
     def _unshare_bookmark_helper(self, engine_ref, dlpx_obj, single_thread):
@@ -513,13 +521,14 @@ class DXIBookmark(DXIBase):
                 ).reference
 
                 selfservice.bookmark.unshare(dlpx_obj.server_session, bmk_ref)
-                self._add_last_job_to_track(dlpx_obj)
-                run_job.track_running_jobs(
-                    engine_ref,
-                    dlpx_obj,
-                    poll=self.poll,
-                    failures=self.failures,
-                )
+                log.print_info(f"Bookmark unshare complete.")
+                # self._add_last_job_to_track(dlpx_obj)
+                # run_job.track_running_jobs(
+                #     engine_ref,
+                #     dlpx_obj,
+                #     poll=self.poll,
+                #     failures=self.failures,
+                # )
         except (exceptions.HttpError, exceptions.RequestError) as err:
             log.print_exception(
                 f"ERROR: Bookmark {self.bookmark_name} could not be unshared. "
@@ -563,13 +572,14 @@ class DXIBookmark(DXIBase):
                 ).reference
 
                 selfservice.bookmark.share(dlpx_obj.server_session, bmk_ref)
-                self._add_last_job_to_track(dlpx_obj)
-                run_job.track_running_jobs(
-                    engine_ref,
-                    dlpx_obj,
-                    poll=self.poll,
-                    failures=self.failures,
-                )
+                log.print_info(f"Bookmark share complete.")
+                # self._add_last_job_to_track(dlpx_obj)
+                # run_job.track_running_jobs(
+                #     engine_ref,
+                #     dlpx_obj,
+                #     poll=self.poll,
+                #     failures=self.failures,
+                # )
         except (exceptions.HttpError, exceptions.RequestError) as err:
             log.print_exception(
                 f"ERROR: Bookmark {self.bookmark_name} could not be shared. "
@@ -612,11 +622,11 @@ class DXIBookmark(DXIBase):
                     ss_bookmark_obj.tags = self.tags.split(",")
                 if self.description:
                     ss_bookmark_obj.description = self.description
-                if self.bookmark_name:
-                    ss_bookmark_obj.name = self.bookmark_name
+                if self.new_bookmark_name:
+                    ss_bookmark_obj.name = self.new_bookmark_name
                 if self.expires:
                     ss_bookmark_obj.expiration = ref.convert_timestamp_toiso(  # noqa
-                        dlpx_obj, self.expires
+                        dlpx_obj.server_session, self.expires
                     )
                 selfservice.bookmark.update(
                     dlpx_obj.server_session, bmk_ref, ss_bookmark_obj
@@ -628,6 +638,7 @@ class DXIBookmark(DXIBase):
                     poll=self.poll,
                     failures=self.failures,
                 )
+                log.print_info(f"Bookmark update complete.")
         except (exceptions.HttpError, exceptions.RequestError) as err:
             log.print_exception(
                 f"ERROR: {self.bookmark_name} could not be updated. "
@@ -671,6 +682,7 @@ class DXIBookmark(DXIBase):
                     poll=self.poll,
                     failures=self.failures,
                 )
+                log.print_info(f"Bookmark delete complete.")
         except (exceptions.HttpError, exceptions.RequestError) as err:
             log.print_exception(
                 f"ERROR: {self.bookmark_name} could not be deleted. "
