@@ -2,6 +2,8 @@
 # Copyright (c) 2021 by Delphix. All rights reserved.
 #
 
+from os.path import basename
+
 from delphixpy.v1_10_2.web import database
 from delphixpy.v1_10_2.web import selfservice
 from delphixpy.v1_10_2.web import user
@@ -9,7 +11,9 @@ from delphixpy.v1_10_2.web import vo
 from dxi._lib import dx_logging
 from dxi._lib import get_references
 from dxi._lib import run_job
+from dxi._lib.dlpx_exceptions import DXIException
 from dxi._lib.run_async import run_async
+from dxi._lib.util import DXIConfigConstantsHelper
 from dxi.dxi_tool_base import DXIBase
 from tabulate import tabulate
 
@@ -22,10 +26,11 @@ class DXIContainerConstants(object):
     ALL_DBS = False
     SINGLE_THREAD = False
     POLL = 20
-    CONFIG = "../../dxi-data/config/dxtools.conf"
-    LOG_FILE_PATH = "../../dxi-data/logs/"
+    CONFIG = DXIConfigConstantsHelper().get_config()
+    LOG_FILE_PATH = DXIConfigConstantsHelper().get_logdir()
     BCK_FILE = None
     USE_BACKUP = False
+    USE_BACKUP = False
     CREATE_BACKUP = False
     ENGINE_ID = "default"
     NAME = None
@@ -45,6 +50,7 @@ class DXIContainer(DXIBase):
         config=DXIContainerConstants.CONFIG,
         log_file_path=DXIContainerConstants.LOG_FILE_PATH,
         poll=DXIContainerConstants.POLL,
+        debug=False,
     ):
         """
         :param engine: An Identifier of Delphix engine in dxtools.conf.
@@ -64,9 +70,10 @@ class DXIContainer(DXIBase):
             single_thread=single_thread,
             engine=engine,
             poll=poll,
-            module_name=__name__,
+            module_name=basename(__file__).split(".")[0],
+            debug=debug,
         )
-        self.display_choices(self)
+        # self.display_choices(self)
         self.container_name = ""
         self.template_name = ""
         self.database_name = ""
@@ -80,6 +87,7 @@ class DXIContainer(DXIBase):
         :rtype: `list`
         """
         try:
+            dx_logging.print_info(f"Running dxi container list.")
             self._execute_operation(self.__list_container_helper)
             return True
         except Exception:
@@ -98,9 +106,9 @@ class DXIContainer(DXIBase):
         :return: Give all containers on a given engine
         :rtype: `list`
         """
-        dlpx_obj = self._initialize_session()
-        self._setup_dlpx_session(dlpx_obj, engine_ref)
         try:
+            dlpx_obj = self._initialize_session()
+            self._setup_dlpx_session(dlpx_obj, engine_ref)
             print_list = []
             with dlpx_obj.job_mode(single_thread):
                 container_list = []
@@ -115,9 +123,7 @@ class DXIContainer(DXIBase):
                 ss_containers = selfservice.container.get_all(
                     dlpx_obj.server_session
                 )
-
                 dx_logging.print_debug(header)
-
                 for ss_container in ss_containers:
                     last_updated = get_references.convert_timestamp(
                         dlpx_obj.server_session, ss_container.last_updated[:-5]
@@ -152,38 +158,42 @@ class DXIContainer(DXIBase):
                             )
                         )
                     )
-                    self._add_last_job_to_track(dlpx_obj)
-            run_job.track_running_jobs(
-                engine_ref, dlpx_obj, poll=self.poll, failures=self.failures
-            )
-            print("\n")
-            print(tabulate(print_list, headers=header, tablefmt="fancy_grid"))
+            #       self._add_last_job_to_track(dlpx_obj)
+            # run_job.track_running_jobs(
+            #     engine_ref, dlpx_obj, poll=self.poll, failures=self.failures
+            # )
+            print(tabulate(print_list, headers=header, tablefmt="github"))
             return container_list
+        except DXIException as err:
+            dx_logging.print_exception(err)
+            self.failures[0] = True
         except Exception as err:
             dx_logging.print_exception(
-                f"ERROR: SS Containers could not be listed. "
-                f"The error was:\n{err}"
+                f"ERROR: An error occurred while listing "
+                f"Self-Service containers.\n {err}"
             )
+            self.failures[0] = True
 
-    def create(self, container_name, template_name, database_name):
+    def create(self, container_name, template_name, db_name):
         """
         :param container_name: Name of the SS Container
         :type container_name: `str`
         :param template_name:  Name of the JS Template to use for the container
         :type template_name: `str`
-        :param database_name: Name of the child database(s) to use for the
+        :param db_name: Name of the child database(s) to use for the
                     SS Container
-        :type database_name: `str`
+        :type db_name: `str`
         :return: created container reference
         :rtype: `str`
         """
-        if not (container_name or template_name or database_name):
-            dx_logging.print_exception("Some values are missing")
+        if not (container_name or template_name or db_name):
+            dx_logging.print_exception("Some required parameters are missing.")
             return
         self.container_name = container_name
         self.template_name = template_name
-        self.database_name = database_name
+        self.database_name = db_name
         try:
+            dx_logging.print_info(f"Running dxi container create")
             self._execute_operation(self.__create_container_helper)
             return True
         except Exception:
@@ -202,10 +212,10 @@ class DXIContainer(DXIBase):
         :return: created container reference
         :rtype: `str`
         """
-        dlpx_obj = self._initialize_session()
-        self._setup_dlpx_session(dlpx_obj, engine_ref)
-        with dlpx_obj.job_mode(single_thread):
-            try:
+        try:
+            dlpx_obj = self._initialize_session()
+            self._setup_dlpx_session(dlpx_obj, engine_ref)
+            with dlpx_obj.job_mode(single_thread):
                 ss_container_params = (
                     vo.JSDataContainerCreateWithoutRefreshParameters()
                 )
@@ -242,11 +252,15 @@ class DXIContainer(DXIBase):
                     failures=self.failures,
                 )
                 return container_ref
-            except (Exception, BaseException) as err:
-                dx_logging.print_exception(
-                    f"Container {self.container_name} was not created. "
-                    f"The error was:\n{str(err)}"
-                )
+        except DXIException as err:
+            dx_logging.print_exception(err)
+            self.failures[0] = True
+        except (Exception, BaseException) as err:
+            dx_logging.print_exception(
+                f"Container {self.container_name} was not created. "
+                f"The error was:\n{str(err)}"
+            )
+            self.failures[0] = True
 
     def delete(self, container_name, keep_vdbs=False):
         """
@@ -261,6 +275,7 @@ class DXIContainer(DXIBase):
         self.container_name = container_name
         self.keep_vdbs = keep_vdbs
         try:
+            dx_logging.print_info(f"Running dxi container delete")
             self._execute_operation(self.__delete_container_helper)
             return True
         except Exception:
@@ -279,10 +294,10 @@ class DXIContainer(DXIBase):
         :return: True if execution succeeds, else False
         :rtype: `bool`
         """
-        dlpx_obj = self._initialize_session()
-        self._setup_dlpx_session(dlpx_obj, engine_ref)
-        with dlpx_obj.job_mode(single_thread):
-            try:
+        try:
+            dlpx_obj = self._initialize_session()
+            self._setup_dlpx_session(dlpx_obj, engine_ref)
+            with dlpx_obj.job_mode(single_thread):
                 if self.keep_vdbs:
                     dx_logging.print_debug("VDB will not be deleted")
                     ss_container_params = vo.JSDataContainerDeleteParameters()
@@ -312,11 +327,15 @@ class DXIContainer(DXIBase):
                     poll=self.poll,
                     failures=self.failures,
                 )
-            except (Exception, BaseException) as err:
-                dx_logging.print_exception(
-                    f"Container {self.container_name} was not deleted. "
-                    f"The error was:\n{str(err)}"
-                )
+        except DXIException as err:
+            dx_logging.print_exception(err)
+            self.failures[0] = True
+        except (Exception, BaseException) as err:
+            dx_logging.print_exception(
+                f"Container {self.container_name} was not deleted. "
+                f"The error was:\n{str(err)}"
+            )
+            self.failures[0] = True
 
     def reset(self, container_name):
         """
@@ -329,6 +348,7 @@ class DXIContainer(DXIBase):
         """
         self.container_name = container_name
         try:
+            dx_logging.print_info(f"Running dxi container reset")
             self._execute_operation(self.__reset_container_helper)
             return True
         except Exception:
@@ -347,10 +367,10 @@ class DXIContainer(DXIBase):
         :return: True if execution succeeds, else False
         :rtype: `bool`
         """
-        dlpx_obj = self._initialize_session()
-        self._setup_dlpx_session(dlpx_obj, engine_ref)
-        with dlpx_obj.job_mode(single_thread):
-            try:
+        try:
+            dlpx_obj = self._initialize_session()
+            self._setup_dlpx_session(dlpx_obj, engine_ref)
+            with dlpx_obj.job_mode(single_thread):
                 selfservice.container.reset(
                     dlpx_obj.server_session,
                     get_references.find_obj_by_name(
@@ -366,11 +386,15 @@ class DXIContainer(DXIBase):
                     poll=self.poll,
                     failures=self.failures,
                 )
-            except (Exception, BaseException) as err:
-                dx_logging.print_exception(
-                    f"ERROR: SS Container was not reset. "
-                    f"The error was:\n{str(err)}"
-                )
+        except DXIException as err:
+            dx_logging.print_exception(err)
+            self.failures[0] = True
+        except (Exception, BaseException) as err:
+            dx_logging.print_exception(
+                f"ERROR: SS Container was not reset. "
+                f"The error was:\n{str(err)}"
+            )
+            self.failures[0] = True
 
     def refresh(self, container_name):
         """
@@ -381,6 +405,7 @@ class DXIContainer(DXIBase):
         """
         self.container_name = container_name
         try:
+            dx_logging.print_info(f"Running dxi container refresh")
             self._execute_operation(self.__refresh_container_helper)
             return True
         except Exception:
@@ -399,10 +424,10 @@ class DXIContainer(DXIBase):
         :return: True if execution succeeds, else False
         :rtype: `bool`
         """
-        dlpx_obj = self._initialize_session()
-        self._setup_dlpx_session(dlpx_obj, engine_ref)
-        with dlpx_obj.job_mode(single_thread):
-            try:
+        try:
+            dlpx_obj = self._initialize_session()
+            self._setup_dlpx_session(dlpx_obj, engine_ref)
+            with dlpx_obj.job_mode(single_thread):
                 selfservice.container.refresh(
                     dlpx_obj.server_session,
                     get_references.find_obj_by_name(
@@ -418,11 +443,15 @@ class DXIContainer(DXIBase):
                     poll=self.poll,
                     failures=self.failures,
                 )
-            except (Exception, BaseException) as err:
-                dx_logging.print_exception(
-                    f"Container {self.container_name} was not refreshed. "
-                    f"The error was:\n{str(err)}"
-                )
+        except DXIException as err:
+            dx_logging.print_exception(err)
+            self.failures[0] = True
+        except (Exception, BaseException) as err:
+            dx_logging.print_exception(
+                f"Container {self.container_name} was not refreshed. "
+                f"The error was:\n{str(err)}"
+            )
+            self.failures[0] = True
 
     def restore(self, container_name, bookmark_name):
         """
@@ -437,6 +466,7 @@ class DXIContainer(DXIBase):
         self.container_name = container_name
         self.bookmark_name = bookmark_name
         try:
+            dx_logging.print_info(f"Running dxi container restore")
             self._execute_operation(self.__restore_container_helper)
             return True
         except Exception:
@@ -453,9 +483,9 @@ class DXIContainer(DXIBase):
             run multi-thread
         :type single_thread: `bool`
         """
-        dlpx_obj = self._initialize_session()
-        self._setup_dlpx_session(dlpx_obj, engine_ref)
-        with dlpx_obj.job_mode(single_thread):
+        try:
+            dlpx_obj = self._initialize_session()
+            self._setup_dlpx_session(dlpx_obj, engine_ref)
             bookmark_params = vo.JSDataContainerRestoreParameters()
             bookmark_params.timeline_point_parameters = (
                 vo.JSTimelinePointBookmarkInput()
@@ -466,7 +496,7 @@ class DXIContainer(DXIBase):
                 self.bookmark_name,
             ).reference
             bookmark_params.force_option = False
-            try:
+            with dlpx_obj.job_mode(single_thread):
                 selfservice.container.restore(
                     dlpx_obj.server_session,
                     get_references.find_obj_by_name(
@@ -483,10 +513,14 @@ class DXIContainer(DXIBase):
                     poll=self.poll,
                     failures=self.failures,
                 )
-            except (Exception, BaseException) as err:
-                dx_logging.print_exception(
-                    f"The container was not restored:\n{str(err)}"
-                )
+        except DXIException as err:
+            dx_logging.print_exception(err)
+            self.failures[0] = True
+        except (Exception, BaseException) as err:
+            dx_logging.print_exception(
+                f"The container was not restored:\n{str(err)}"
+            )
+            self.failures[0] = True
 
     def connection_info(self, container_name):
         """
@@ -498,6 +532,7 @@ class DXIContainer(DXIBase):
         """
         self.container_name = container_name
         try:
+            dx_logging.print_info(f"Running dxi container connection_info")
             self._execute_operation(self.__connection_info_helper)
             return True
         except Exception:
@@ -514,12 +549,12 @@ class DXIContainer(DXIBase):
             run multi-thread
         :type single_thread: `bool`
         """
-        dlpx_obj = self._initialize_session()
-        self._setup_dlpx_session(dlpx_obj, engine_ref)
-        headers = ["VDB", "Host", "DB Name", "DB Version", "JDBC"]
-        connection_list = []
-        with dlpx_obj.job_mode(single_thread):
-            try:
+        try:
+            dlpx_obj = self._initialize_session()
+            self._setup_dlpx_session(dlpx_obj, engine_ref)
+            headers = ["VDB", "Host", "DB Name", "DB Version", "JDBC"]
+            connection_list = []
+            with dlpx_obj.job_mode(single_thread):
                 layout_ref = get_references.find_obj_by_name(
                     dlpx_obj.server_session,
                     selfservice.container,
@@ -562,11 +597,15 @@ class DXIContainer(DXIBase):
                         connection_list, headers=headers, tablefmt="fancy_grid"
                     )
                 )
-            except (Exception, BaseException) as err:
-                dx_logging.print_exception(
-                    f"Failed to find connection info"
-                    f"{self.container_name}:\n{str(err)}"
-                )
+        except DXIException as err:
+            dx_logging.print_exception(err)
+            self.failures[0] = True
+        except (Exception, BaseException) as err:
+            dx_logging.print_exception(
+                f"Failed to find connection info"
+                f"{self.container_name}:\n{str(err)}"
+            )
+            self.failures[0] = True
 
     def add_owner(self, container_name, owner_name):
         """
@@ -580,6 +619,7 @@ class DXIContainer(DXIBase):
         self.container_name = container_name
         self.owner_name = owner_name
         try:
+            dx_logging.print_info(f"Running dxi container add_owner")
             self._execute_operation(self.__add_owner_helper)
             return True
         except Exception:
@@ -596,11 +636,11 @@ class DXIContainer(DXIBase):
             run multi-thread
         :type single_thread: `bool`
         """
-        dlpx_obj = self._initialize_session()
-        self._setup_dlpx_session(dlpx_obj, engine_ref)
-        with dlpx_obj.job_mode(single_thread):
-            owner_params = vo.JSDataContainerModifyOwnerParameters()
-            try:
+        try:
+            dlpx_obj = self._initialize_session()
+            self._setup_dlpx_session(dlpx_obj, engine_ref)
+            with dlpx_obj.job_mode(single_thread):
+                owner_params = vo.JSDataContainerModifyOwnerParameters()
                 owner_params.owner = get_references.find_obj_by_name(
                     dlpx_obj.server_session, user, self.owner_name
                 ).reference
@@ -620,11 +660,15 @@ class DXIContainer(DXIBase):
                     poll=self.poll,
                     failures=self.failures,
                 )
-            except (Exception, BaseException) as err:
-                dx_logging.print_exception(
-                    f"The user was not added from the container "
-                    f"{self.container_name}:\n{str(err)}"
-                )
+        except DXIException as err:
+            dx_logging.print_exception(err)
+            self.failures[0] = True
+        except (Exception, BaseException) as err:
+            dx_logging.print_exception(
+                f"The user was not added from the container "
+                f"{self.container_name}:\n{str(err)}"
+            )
+            self.failures[0] = True
 
     def remove_owner(self, container_name, owner_name):
         """
@@ -638,6 +682,7 @@ class DXIContainer(DXIBase):
         self.container_name = container_name
         self.owner_name = owner_name
         try:
+            dx_logging.print_info(f"Running dxi container remove_owner")
             self._execute_operation(self.__remove_owner_helper)
             return True
         except Exception:
@@ -654,11 +699,11 @@ class DXIContainer(DXIBase):
             run multi-thread
         :type single_thread: `bool`
         """
-        dlpx_obj = self._initialize_session()
-        self._setup_dlpx_session(dlpx_obj, engine_ref)
-        with dlpx_obj.job_mode(single_thread):
-            owner_params = vo.JSDataContainerModifyOwnerParameters()
-            try:
+        try:
+            dlpx_obj = self._initialize_session()
+            self._setup_dlpx_session(dlpx_obj, engine_ref)
+            with dlpx_obj.job_mode(single_thread):
+                owner_params = vo.JSDataContainerModifyOwnerParameters()
                 owner_params.owner = get_references.find_obj_by_name(
                     dlpx_obj.server_session, user, self.owner_name
                 ).reference
@@ -679,8 +724,12 @@ class DXIContainer(DXIBase):
                     poll=self.poll,
                     failures=self.failures,
                 )
-            except Exception as err:
-                dx_logging.print_exception(
-                    f"The user was not removed to container "
-                    f"{self.container_name}. The error was:\n{err}"
-                )
+        except DXIException as err:
+            dx_logging.print_exception(err)
+            self.failures[0] = True
+        except Exception as err:
+            dx_logging.print_exception(
+                f"The user was not removed to container "
+                f"{self.container_name}. The error was:\n{err}"
+            )
+            self.failures[0] = True
