@@ -2,6 +2,7 @@
 # Copyright (c) 2021 by Delphix. All rights reserved.
 #
 
+import copy
 import time
 from abc import ABC
 from os.path import basename
@@ -11,6 +12,7 @@ from dxi._lib import dx_logging
 from dxi._lib import get_session
 from dxi._lib import run_job
 from dxi._lib import util
+from dxi._lib.dlpx_exceptions import DXIException
 
 
 class DXIBase(ABC):
@@ -28,18 +30,22 @@ class DXIBase(ABC):
         module_name,
         engine=None,
         parallel=5,
+        debug=False
     ):
+        self.debug=debug
         self.parallel = parallel
         self.poll = poll
         self.single_thread = single_thread
         self.module_name = module_name
+        self.log_file_path = util.find_log_path(log_file_path, module_name)
         self.config = util.find_config_path(config)
         self.engine = engine
-        self.log_file_path = util.find_log_path(log_file_path, module_name)
         self.dx_session_obj = self._initialize_session()
         self.time_start = time.time()
         self.failures = [False]
-        dx_logging.logging_est(self.log_file_path)
+        # self.session_mgr = self._initialize_session() # TODO
+        dx_logging.logging_est(self.log_file_path,self.debug)
+
 
     def _initialize_session(self):
         dx_session_obj = get_session.GetSession()
@@ -53,7 +59,8 @@ class DXIBase(ABC):
         dx_logging.print_debug("-" * 79)
         dx_logging.print_debug("Provided parameters for execution")
         dx_logging.print_debug("-" * 79)
-        attrs = vars(obj)
+        obj2 = copy.deepcopy(obj)
+        attrs = vars(obj2)
         pw_keys = [
             key
             for key, value in attrs.items()
@@ -66,17 +73,18 @@ class DXIBase(ABC):
         )
         dx_logging.print_debug("-" * 79)
 
-    def _execute_operation(self, function_ref):
+    def _execute_operation(self, run_async_function_ref, helper_ref=None):
         """
-        :param function_ref: A function reference
-        :type function_ref: `callable`
+        :param run_async_function_ref: A function reference
+        :type run_async_function_ref: `callable`
         """
         try:
             for each in run_job.run_job_mt(
-                function_ref,
-                self.dx_session_obj,
+                run_async_function_ref,
+                self.dx_session_obj,  # engine data
                 self.engine,
                 self.single_thread,
+                helper_ref=helper_ref,
             ):
                 each.join()
 
@@ -100,14 +108,16 @@ class DXIBase(ABC):
         """
         try:
             # Setup the connection to the Delphix DDP
-            dx_logging.print_debug("Setting up the dlpx session")
+            dx_logging.print_debug("Initiating session with Delphix Engine.")
             dlpx_obj.dlpx_session(
                 engine_ref["ip_address"],
                 engine_ref["username"],
                 engine_ref["password"],
                 engine_ref["use_https"],
             )
-            dx_logging.print_debug("Connection established")
+            dx_logging.print_debug("Session with Delphix Engine established.")
+        except DXIException as err:
+            raise err
         except (dlpx_exceptions.DlpxException, Exception) as err:
             dx_logging.print_exception(
                 f"ERROR: {basename(__file__)} encountered an error "
