@@ -14,6 +14,7 @@ from dxi._lib.dxi_constants import EnvironmentOps
 from dxi._lib.dxi_constants import EnvironmentTypes
 from dxi._lib.dxi_constants import HostTypes
 from dxi._lib.run_async import run_async
+from dxi._lib.util import DXIConfigConstantsHelper
 from dxi.dxi_tool_base import DXIBase
 from tabulate import tabulate
 
@@ -25,8 +26,8 @@ class EnvironmentConstants(object):
 
     SINGLE_THREAD = False
     POLL = 20
-    CONFIG = "../../dxi-data/config/dxtools.conf"
-    LOG_FILE_PATH = "../../dxi-data/logs/"
+    CONFIG = DXIConfigConstantsHelper().get_config()
+    LOG_FILE_PATH = DXIConfigConstantsHelper().get_logdir()
     ENGINE_ID = "default"
     PARALLEL = 5
     TYPE = None
